﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace ChartTrendlines
{
    class GasPriceData : Control
    {
        public static DependencyProperty DateProperty =
        DependencyProperty.Register("Date", typeof(DateTime), typeof(GasPriceData), null);

        public DateTime Date
        {
            get { return (DateTime)GetValue(DateProperty); }
            set { SetValue(DateProperty, value); }
        }

        public static DependencyProperty PriceProperty =
          DependencyProperty.Register("Price", typeof(double), typeof(GasPriceData), null);

        public double Price
        {
            get { return (double)GetValue(PriceProperty); }
            set { SetValue(PriceProperty, value); }
        }

        public GasPriceData(DateTime dt, double p)
        {
          Date = dt;
          Price = p;
        }
    }

    public class CSVData
    {
        private List<string> _fields = new List<string>();
        private List<string[]> _records = new List<string[]>();

        List<string> Fields
        {
            get { return _fields; }
        }

        List<string[]> Records
        {
            get { return _records; }
        }

        public int Length
        {
            get { return _records.Count; }
        }

        public string this[int i, int j]
        {
            get
            {
                string[] ss = Records[i];
                if (j < 0 || j >= ss.Length)
                    throw new ArgumentException("j");

                return ss[j];
            }
        }

        public string this[int i, string name]
        {
            get
            {
                string[] ss = Records[i];
                int j = Fields.IndexOf(name);
                if (j < 0 || j >= ss.Length)
                    throw new ArgumentException("name");

                return ss[j];
            }
        }

        public void Read(Stream stream, bool readNames)
        {
            if (stream == null)
                throw new ArgumentNullException("stream");

            Fields.Clear();
            Records.Clear();

            if (stream != null)
            {
                using (StreamReader sr = new StreamReader(stream))
                {
                    int i = 0;
                    while (sr.Peek() > -1)
                    {
                        string line = sr.ReadLine();

                        if (line.StartsWith("#"))
                            continue;

                        string[] ss = line.Split(',');

                        if (readNames && Fields.Count == 0)
                            Fields.AddRange(ss);
                        else
                        {
                            Records.Add(ss);
                            i++;
                        }
                    }
                    sr.Close();
                }
            }
        }
    }
}
